@@ -45,7 +45,8 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <memory_mosq.h>
 
 #ifdef REAL_WITH_MEMORY_TRACKING
-static unsigned long memcount;
+static unsigned long memcount = 0;
+static unsigned long max_memcount = 0;
 #endif
 
 void *_mosquitto_calloc(size_t nmemb, size_t size)
@@ -54,6 +55,9 @@ void *_mosquitto_calloc(size_t nmemb, size_t size)
 
 #ifdef REAL_WITH_MEMORY_TRACKING
     memcount += malloc_usable_size(mem);
+    if(memcount > max_memcount){
+        max_memcount = memcount;
+    }
 #endif
 
     return mem;
@@ -73,6 +77,9 @@ void *_mosquitto_malloc(size_t size)
 
 #ifdef REAL_WITH_MEMORY_TRACKING
     memcount += malloc_usable_size(mem);
+    if(memcount > max_memcount){
+        max_memcount = memcount;
+    }
 #endif
 
     return mem;
@@ -83,6 +90,11 @@ unsigned long _mosquitto_memory_used(void)
 {
     return memcount;
 }
+
+unsigned long _mosquitto_max_memory_used(void)
+{
+    return max_memcount;
+}
 #endif
 
 void *_mosquitto_realloc(void *ptr, size_t size)
@@ -97,6 +109,9 @@ void *_mosquitto_realloc(void *ptr, size_t size)
 
 #ifdef REAL_WITH_MEMORY_TRACKING
     memcount += malloc_usable_size(mem);
+    if(memcount > max_memcount){
+        max_memcount = memcount;
+    }
 #endif
 
     return mem;
@@ -108,6 +123,9 @@ char *_mosquitto_strdup(const char *s)
 
 #ifdef REAL_WITH_MEMORY_TRACKING
     memcount += malloc_usable_size(str);
+    if(memcount > max_memcount){
+        max_memcount = memcount;
+    }
 #endif
 
     return str;
